@@ -35,7 +35,7 @@
 #include <winsock2.h>
 #include <ws2tcpip.h>
 #endif
-#ifdef SYS_SOCKET_H
+#ifdef HAVE_SYS_SOCKET_H
 #include <sys/socket.h>
 #endif
 #ifdef HAVE_NETINET_IN_H
